
local eventLocations, _WorldMapSize, _QuestHelper_ZoneLookup, _QuestHelper_Zones, _DISTINCT_IDS, _IdsToSkip

-- Returns the Levenshtein distance between the two given strings
-- credit to https://gist.github.com/Badgerati/3261142
local function _Levenshtein(str1, str2)
    local len1 = string.len(str1)
    local len2 = string.len(str2)
    local matrix = {}
    local cost = 0
    -- quick cut-offs to save time
    if (len1 == 0) then
        return len2
    elseif (len2 == 0) then
        return len1
    elseif (str1 == str2) then
        return 0
    end
    -- initialise the base matrix values
    for i = 0, len1, 1 do
        matrix[i] = {}
        matrix[i][0] = i
    end
    for j = 0, len2, 1 do
        matrix[0][j] = j
    end
    -- actual Levenshtein algorithm
    for i = 1, len1, 1 do
        for j = 1, len2, 1 do
            if (string.byte(str1,i) == string.byte(str2,j)) then
                cost = 0
            else
                cost = 1
            end
            matrix[i][j] = math.min(matrix[i-1][j] + 1, matrix[i][j-1] + 1, matrix[i-1][j-1] + cost)
        end
    end
    -- return the last value - this is the Levenshtein distance
    return matrix[len1][len2]
end

local cancelExtract = false

function __Cancel()
    cancelExtract = true
end

function __Extract()
    Questie.db.char.skippedIds = {}
    print("Extracting...\n")
    local triggerCorrections = {}

    local entryId = 1
    local retryCount = 0

    Questie.db.char.erronousEntries = {}

    local timer
    timer = C_Timer.NewTicker(0.1, function()
        local questId = _DISTINCT_IDS[entryId]

        if (cancelExtract) then
            timer:Cancel()
            print("Canceling extraction")
            return
        end

        if (_IdsToSkip[questId]) then
            entryId = entryId + 1
            return
        end

        if (not questId) then
            timer:Cancel()
            print("\nExtraction done...")
            return
        end

        print("Checking entry", entryId, questId)
        local objectives = C_QuestLog.GetQuestObjectives(questId)

        if (retryCount == 1) then
            --print("Skipping questId", questId, "because API give no objectives")
            retryCount = 0
            entryId = entryId + 1
            Questie.db.char.skippedIds[questId] = true
            return
        end

        if (not objectives) then
            --print("invalid objectives for " .. questId)
            retryCount = retryCount + 1
            return
        end

        entryId = entryId + 1

        if (not next(objectives)) then
            --print("Skipping questId", questId)
            return
        end

        for _, objective in pairs(objectives) do
            if (objective.type == "event") then
                print("QuestId with event objective: " .. questId)

                local entryFound = false
                for triggerText, locationData in pairs(eventLocations) do
                    if (_Levenshtein(triggerText, objective.text) < 5) then
                        print("Found matching triggerText:", triggerText)
                        entryFound = true

                        local zoneTriggers = {}
                        for _, pos in pairs(locationData.pos) do
                            local pair = _QuestHelper_ZoneLookup[pos[1]] -- pair[1] = continentId, pair[2] = zoneId
                            local zoneName = _QuestHelper_Zones[pair[1]][pair[2]]:gsub("%s+", "") -- _WorldMapSize -> zoneData uses zoneName indizes
                            if (zoneName == "Zul'Drak") then
                                zoneName = "ZulDrak"
                            end
                            if (not _WorldMapSize[pair[1]]) then
                                print("Objective has no matching zoneId", pair[1], pair[2])
                                Questie.db.char.erronousEntries[questId] = {pair[1], pair[2], zoneName, triggerText}
                                return
                            end
                            if (not zoneName or not pair[1] or not _WorldMapSize[pair[1]].zoneData[zoneName]) then
                                Questie.db.char.erronousEntries[questId] = {pair[1], pair[2], zoneName, triggerText}
                                return
                            end
                            local zoneId = _WorldMapSize[pair[1]].zoneData[zoneName].mapID

                            if (not zoneTriggers[zoneId]) then
                                zoneTriggers[zoneId]={}
                            end

                            table.insert(zoneTriggers[zoneId], {pos[2] * 100,pos[3] * 100})
                        end

                        triggerCorrections[questId] = {
                            ["questKeys.triggerEnd"] = {objective.text, zoneTriggers} -- "questKeys.triggerEnd" needs to be replaces with just questKeys.triggerEnd afterwards
                        }
                        break
                    end
                end

                if (not entryFound) then
                    print("No QuestHelper entry found for", questId, objective.text)
                    Questie.db.char.erronousEntries[questId] = {objective.text}
                end
            end
        end
    end)

    Questie.db.char.extracted = triggerCorrections
end

-- QuestHelper triggerEnd data
eventLocations = {
    ["\"Crimson Dawn\" Revealed"]={pos={{78,0.5509,0.6612,100},{78,0.613,0.677,69},{78,0.5531,0.7037,64},{78,0.5832,0.6563,43},{78,0.5576,0.6217,38}}},
    ["15 Patients Saved!"]={pos={{10,0.6779,0.4906,100}}},
    ["A Solvent Spirit"]={pos={{7,0.5942,0.7185,100}}},
    ["A Tale of Sorrow"]={pos={{46,0.3424,0.6602,100}}},
    ["Accompany Brann Bronzebeard to Frosthold."]={pos={{73,0.3008,0.739,100}}},
    ["Advice from Lady Prestor"]={pos={{36,0.8005,0.3839,100}}},
    ["Aid Faerleia in killing the Pyrewood Council"]={pos={{35,0.4651,0.7405,100}}},
    ["Akali unfettered from his chains."]={pos={{75,0.7864,0.2511,100}}},
    ["Alliance Banner Defended"]={pos={{70,0.6489,0.4003,100}}},
    ["Alliance Deserter Delivered"]={pos={{65,0.5528,0.5086,100}}},
    ["Answer Braug Dimspirit's question correctly"]={pos={{6,0.7874,0.4562,100}}},
    ["Answer Parqual Fintallas' question correctly"]={pos={{45,0.577,0.6521,100}}},
    ["Apexis Emanations attained"]={pos={{54,0.2871,0.4669,100},{54,0.2736,0.6841,32},{54,0.3189,0.6354,20}}},
    ["Apexis Vibrations attained"]={pos={{54,0.3338,0.5187,100},{54,0.2875,0.4665,51},{54,0.2739,0.6854,27},{54,0.3175,0.6374,23}}},
    ["Ark of Ssslith safely returned to Sporeggar"]={pos={{57,0.1966,0.5065,100}}},
    ["Assist King Varian Wrynn"]={pos={{45,0.5375,0.8996,100}}},
    ["Attack thwarted"]={pos={{60,0.5178,0.2075,100}}},
    ["Attempt to purify the Darkstone of Terrok"]={pos={{55,0.3084,0.4203,100}}},
    ["Battle for Crusaders' Pinnacle"]={pos={{71,0.8006,0.7181,100}}},
    ["Beat Bartleby"]={pos={{36,0.7667,0.5297,100}}},
    ["Beat Down \"Dirty\" Larry and Get Information"]={pos={{60,0.4382,0.2827,100}}},
    ["Blacksilt Scouts Tagged"]={pos={{9,0.4708,0.9461,100},{9,0.5177,0.9019,100}}},
    ["Bloodspore Flower Used"]={pos={{65,0.5207,0.5246,100}}},
    ["Bonker Togglevolt escorted to safety."]={pos={{65,0.5384,0.1385,100}}},
    ["Break a Few Eggs"]={pos={{7,0.646,0.7317,100}}},
    ["Brokentoe Defeated"]={pos={{58,0.434,0.2063,100}}},
    ["Burning Legion warp-gate sabotaged"]={pos={{59,0.4813,0.6339,100}}},
    ["Captain Skyshatter Defeated"]={pos={{53,0.647,0.8497,100}}},
    ["Captured Protectorate Vanguard Escorted"]={pos={{59,0.5886,0.3244,100}}},
    ["Carnage Defeated"]={pos={{71,0.3091,0.2956,100}}},
    ["Catch 10 torches in a row."]={pos={{36,0.487,0.7075,100},{25,0.6204,0.2781,82},{23,0.2217,0.269,78},{1,0.4715,0.3669,64},{45,0.6447,0.0807,59}}},
    ["Catch 4 torches in a row."]={pos={{36,0.4879,0.7088,100},{25,0.6211,0.2759,90},{1,0.4706,0.3683,64},{45,0.6456,0.0805,61},{23,0.221,0.2672,60}}},
    ["Caverns of Time Explained"]={pos={{8,0.5889,0.543,100}}},
    ["City of Light"]={pos={{60,0.5047,0.4297,100}}},
    ["Clean up a stink bomb that's been dropped on Southshore!"]={pos={{48,0.5001,0.5813,100}}},
    ["Cleanse the Thunderhorn Water Well"]={pos={{22,0.4454,0.4547,100}}},
    ["Cleanse the Wildmane Well"]={pos={{22,0.4275,0.1416,100}}},
    ["Cleanse the Winterhoof Water Well"]={pos={{22,0.5362,0.6621,100}}},
    ["Complete the Second Trial"]={pos={{41,0.4334,0.287,100}}},
    ["Complete the Trial of the Lake."]={pos={{20,0.3614,0.4164,100}}},
    ["Control Four Bases."]={pos={{60,0.6754,0.3372,100},{39,0.4622,0.4525,60},{25,0.7026,0.9043,41},{36,0.835,0.3402,41}}},
    ["Conversation with Loramus"]={pos={{15,0.608,0.6636,100}}},
    ["Corlok the Vet Defeated"]={pos={{53,0.647,0.8476,100}}},
    ["Council with Eitrigg."]={pos={{1,0.3416,0.3914,100}}},
    ["Create the Scepter of Celebras"]={pos={{4,0.3597,0.644,100}}},
    ["Crimson Sigil Forces Annihilated"]={pos={{53,0.5176,0.7282,100}}},
    ["Cure Completed"]={pos={{48,0.6156,0.1923,100}}},
    ["Deathblow to the Legion"]={pos={{59,0.2956,0.1415,100}}},
    ["Declaration of Power"]={pos={{9,0.6857,0.6787,100}}},
    ["Defeat Calvin Montague"]={pos={{43,0.3819,0.5673,100}}},
    ["Defeat Dashel Stonefist"]={pos={{36,0.7393,0.5915,100}}},
    ["Defeat Drek'thar."]={pos={{26,0.3483,0.7513,100},{60,0.6744,0.343,86},{36,0.833,0.3417,63},{25,0.7008,0.9017,49},{26,0.3971,0.8093,34}}},
    ["Defeat Tapoke Jahn"]={pos={{51,0.1089,0.5934,100}}},
    ["Defeat Vanndar Stormpike."]={pos={{26,0.6675,0.5175,100},{60,0.668,0.5639,48},{26,0.6283,0.5981,33},{1,0.7925,0.3107,32}}},
    ["Defeat Vorsha the Lasher"]={pos={{2,0.0959,0.2758,100}}},
    ["Defend Professor Phizzlethorpe"]={pos={{39,0.3387,0.8058,100}}},
    ["Defend Shakes O'Breen"]={pos={{39,0.3191,0.8169,100}}},
    ["Defend Theramore Docks from Tethyr"]={pos={{10,0.6996,0.5204,100}}},
    ["Destroy a southern tower in Wintergrasp"]={pos={{74,0.25,0.5855,100},{74,0.5015,0.6525,86},{74,0.7902,0.6262,83}}},
    ["Destroy one of the three southern towers"]={pos={{74,0.5094,0.651,100},{74,0.7864,0.6263,86},{74,0.2511,0.5849,62}}},
    ["Destroy the command tent and plant the Scourge banner in the camp"]={pos={{50,0.4071,0.5203,100}}},
    ["Devilsaur stabbed with barb"]={pos={{18,0.6851,0.3122,100},{18,0.5327,0.6025,97},{18,0.6766,0.5817,97},{18,0.6687,0.2609,93},{18,0.7391,0.3857,83}}},
    ["Diagnosis Complete"]={pos={{36,0.8005,0.701,100}}},
    ["Discover Darkwhisper Gorge"]={pos={{19,0.6009,0.7344,100}}},
    ["Discover and examine the Eastern Crystal Pylon"]={pos={{18,0.7727,0.4998,100}}},
    ["Discover and examine the Northern Crystal Pylon"]={pos={{18,0.5651,0.1241,100}}},
    ["Discover and examine the Western Crystal Pylon"]={pos={{18,0.2377,0.5915,100}}},
    ["Discover the Brood of Nozdormu."]={pos={{8,0.6344,0.5063,100}}},
    ["Discover the Ghostfish mystery"]={pos={{72,0.4889,0.6229,100}}},
    ["Discover the secret of the Altar of Elune"]={pos={{19,0.6485,0.6373,100}}},
    ["Disperse the Neutralizing Agent"]={pos={{3,0.7703,0.5822,100}}},
    ["Dorius Escort"]={pos={{32,0.7446,0.1941,100}}},
    ["Dornaa taken to Aeris Landing"]={pos={{58,0.3146,0.5745,100}}},
    ["Dornaa taken to Farseer Nobundo"]={pos={{12,0.3081,0.2988,100}}},
    ["Dornaa taken to the Caverns of Time"]={pos={{8,0.605,0.5772,100}}},
    ["Dornaa taken to the Dark Portal"]={pos={{56,0.8831,0.5031,100}}},
    ["Dornaa taken to the Ring of Observance"]={pos={{55,0.397,0.6464,100}}},
    ["Dornaa taken to the Seat of the Naaru"]={pos={{12,0.5661,0.4075,100}}},
    ["Draenei Survivors Saved"]={pos={{3,0.7522,0.4688,100}}},
    ["Dragonmaw Forces Defeated"]={pos={{53,0.57,0.581,100},{53,0.6425,0.3095,56}}},
    ["Drain Located"]={pos={{57,0.5041,0.4091,100}}},
    ["Drive Overlord Mok'Morokk from Brackenwall Village"]={pos={{10,0.3639,0.3145,100}}},
    ["Earthmender Wilda Escorted to Safety"]={pos={{53,0.5313,0.2521,100}}},
    ["Elemental Lord Defeated"]={pos={{75,0.4801,0.5672,100}}},
    ["Energize a Crystal Ward"]={pos={{64,0.4792,0.3436,100},{64,0.4868,0.3052,47}}},
    ["Enter the Dead Fields"]={pos={{35,0.4613,0.2051,100},{35,0.4549,0.235,51}}},
    ["Enter the Master's Glaive"]={pos={{16,0.3899,0.8584,100}}},
    ["Enter the Rethban Caverns"]={pos={{30,0.1923,0.2523,100}}},
    ["Erland must reach Rane Yorick"]={pos={{35,0.5437,0.1337,100}}},
    ["Escort Anchorite Truuen to Uther's Tomb"]={pos={{50,0.5206,0.8325,100}}},
    ["Escort Bessy on her way home."]={pos={{59,0.577,0.8498,100}}},
    ["Escort Corporal Keeshan back to Redridge"]={pos={{30,0.3338,0.4867,100}}},
    ["Escort Cryo-Engineer Sha'heen"]={pos={{55,0.3962,0.5756,100}}},
    ["Escort Engineer Helice out of Swindlegrin's Dig"]={pos={{72,0.3726,0.5056,100}}},
    ["Escort Father Kamaros to safety"]={pos={{71,0.3196,0.5712,100}}},
    ["Escort Galen out of the Fallow Sanctuary."]={pos={{46,0.5304,0.2957,100}}},
    ["Escort Gilthares Firebough back to Ratchet"]={pos={{11,0.6227,0.3909,100}}},
    ["Escort Gizelton Caravan past Kolkar Centaur Village"]={pos={{4,0.6721,0.5649,100}}},
    ["Escort Gizelton Caravan past Mannoroc Coven"]={pos={{4,0.5567,0.6781,100}}},
    ["Escort Isla Starmane to safety"]={pos={{55,0.675,0.3727,100}}},
    ["Escort Kayra Longmane to safety"]={pos={{57,0.7976,0.711,100}}},
    ["Escort Kerlonian Evershade to Maestra's Post"]={pos={{2,0.2676,0.369,100}}},
    ["Escort Lakota Windsong from the Darkcloud Pinnacle."]={pos={{14,0.3093,0.3713,100}}},
    ["Escort Lurgglbr to safety"]={pos={{65,0.4135,0.1629,100}}},
    ["Escort Miran to the excavation site"]={pos={{29,0.6512,0.6577,100}}},
    ["Escort OOX-09/HL to the shoreline beyond Overlook Cliff"]={pos={{42,0.7913,0.6138,100}}},
    ["Escort OOX-17/TN to Steamwheedle Port"]={pos={{8,0.6706,0.2316,100}}},
    ["Escort OOX-22/FE to the dock along the Forgotten Coast"]={pos={{17,0.4562,0.4338,100}}},
    ["Escort Pao'ka from Highperch"]={pos={{14,0.1514,0.3264,100}}},
    ["Escort Prospector Remtravel"]={pos={{16,0.3568,0.8401,100}}},
    ["Escort Ranger Lilatha back to the Farstrider Enclave"]={pos={{44,0.7224,0.3025,100}}},
    ["Escort Rin'ji to safety"]={pos={{42,0.3458,0.5632,100}}},
    ["Escort Ringo to Spraggle Frock at Marshal's Refuge"]={pos={{18,0.4371,0.0829,100}}},
    ["Escort Ruul from the Thistlefurs."]={pos={{2,0.3853,0.3731,100}}},
    ["Escort Skywing"]={pos={{55,0.5571,0.6968,100}}},
    ["Escort The Defias Traitor to discover where VanCleef is hiding"]={pos={{49,0.4256,0.7153,100}}},
    ["Escort Therylune away from the Master's Glaive"]={pos={{16,0.4051,0.8708,100}}},
    ["Escort Wizzlecrank out of the Venture Co. drill site"]={pos={{11,0.5535,0.0767,100}}},
    ["Escort Wounded Blood Elf Pilgrim to Falcon Watch"]={pos={{56,0.2708,0.6193,100}}},
    ["Escort the Injured Goblin Miner to K3."]={pos={{73,0.4027,0.791,100}}},
    ["Escort the Injured Rainspeaker Oracle to Rainspaker Canopy"]={pos={{72,0.5359,0.5676,100}}},
    ["Escort the Maxx A. Million Mk. V safely through the Ruins of Enkaat"]={pos={{59,0.3153,0.5648,100}}},
    ["Ethereum Conduit Sabotaged"]={pos={{59,0.5642,0.4268,100}}},
    ["Explore the Boha'mu Ruins"]={pos={{57,0.4412,0.6898,100}}},
    ["Explore the Hidden Chamber"]={pos={{27,0.3522,0.1033,100}}},
    ["Explore the craters in Shatter Scar Vale"]={pos={{13,0.4105,0.4207,100}}},
    ["Explore the waters of the Forgotten Pools"]={pos={{11,0.4506,0.2256,100}}},
    ["Extend Peace Offering to Shaman Vekjik"]={pos={{72,0.5134,0.6467,100}}},
    ["Face Lunaclaw and earn the strength of body and heart it possesses."]={pos={{16,0.4334,0.4587,100},{11,0.4197,0.6082,89}}},
    ["Fallen Heroes Defeated"]={pos={{71,0.3081,0.2923,100}}},
    ["Fallen Sky Ridge Revitalized"]={pos={{56,0.129,0.3685,100}}},
    ["Final Thunderlord artifact discovered"]={pos={{54,0.5276,0.5889,100}}},
    ["Find Huldar, Miran, and Saean"]={pos={{29,0.5112,0.6894,100}}},
    ["Find Krun Spinebreaker"]={pos={{56,0.3359,0.4361,100}}},
    ["Find Magus Rimtori's camp"]={pos={{15,0.5931,0.3118,100}}},
    ["Find a corrupt furbolg camp"]={pos={{16,0.3964,0.5321,100}}},
    ["Find the Spider God's Name"]={pos={{8,0.3873,0.1988,100}}},
    ["Find where Gol'dir is being held"]={pos={{26,0.6058,0.4385,100}}},
    ["First triangulation point discovered"]={pos={{59,0.6667,0.3386,100}}},
    ["Fizzcrank Pumping Station environs inspected."]={pos={{65,0.6517,0.252,100}}},
    ["Fizzcrank's tale listened to."]={pos={{65,0.5701,0.1869,100}}},
    ["Fjord Rock Falcon Fed"]={pos={{70,0.7526,0.6491,100}}},
    ["Forge Camps Surveyed"]={pos={{58,0.2722,0.4305,100}}},
    ["Free Raschal."]={pos={{17,0.7214,0.6385,100}}},
    ["Free the Kurenai Captive"]={pos={{58,0.316,0.3878,100}}},
    ["Free the Mag'har Captive"]={pos={{58,0.3175,0.3876,100}}},
    ["From The Wreckage...."]={pos={{7,0.6255,0.5994,100}}},
    ["Frostwolf Muzzled and Returned"]={pos={{60,0.6675,0.5683,100},{1,0.788,0.3131,95},{26,0.6653,0.5167,60},{60,0.5605,0.8115,29},{45,0.5622,0.8597,27}}},
    ["Fully Investigate The Blood Furnace"]={pos={{56,0.459,0.5194,100}}},
    ["Fully explore Frostmane Hold"]={pos={{28,0.2153,0.5218,100}}},
    ["Garm Teleporter Activated"]={pos={{73,0.4102,0.8529,100}}},
    ["Gauge Neeru Fireblade's reaction to you being a member of the Burning Blade"]={pos={{1,0.4961,0.5044,100}}},
    ["Give Gerard a Drink"]={pos={{37,0.4093,0.5394,100}}},
    ["Go Harpoon Surfing"]={pos={{70,0.6008,0.6206,100}}},
    ["Go to the Mor'shan Rampart in the Barrens."]={pos={{11,0.479,0.0535,100}}},
    ["Go to the Westfall Lighthouse."]={pos={{49,0.304,0.8561,100}}},
    ["Go to the bank in Darnassus, otherwise known as the Bough of the Eternals."]={pos={{21,0.4132,0.4352,100}}},
    ["Go to the docks of Ratchet in the Barrens."]={pos={{11,0.6296,0.3804,100}}},
    ["Go to the old Lordaeron Throne Room that lies just before descending into the Undercity."]={pos={{45,0.6598,0.3617,100}}},
    ["Go to the top of the Stonewrought Dam in Loch Modan."]={pos={{29,0.4762,0.1434,100}}},
    ["Goblin Transponder"]={pos={{38,0.2757,0.7742,100}}},
    ["Gold Dust Exchange"]={pos={{37,0.3859,0.8393,100}}},Goldtooth={pos={{37,0.4172,0.7809,100}}},
    ["Goretusk Liver Pie"]={pos={{49,0.539,0.43,100}}},
    ["Harrison has escorted you to safety."]={pos={{69,0.7351,0.2402,100}}},
    ["Hear the Tale of the Blademaster"]={pos={{58,0.7382,0.6259,100}}},
    ["Help Akama and Maiev enter the Black Temple."]={pos={{53,0.7102,0.4612,100}}},
    ["Help Arei get to Safety"]={pos={{13,0.4941,0.1455,100}}},
    ["Help Emily and Mr. Floppy return to the camp"]={pos={{69,0.5381,0.3333,100}}},
    ["Help Stinky find Bogbean Leaves"]={pos={{10,0.4887,0.246,100}}},
    ["Help Volcor escape the cave"]={pos={{16,0.4453,0.8498,100}}},
    ["Help Volcor to the road"]={pos={{16,0.4192,0.8178,100}}},
    ["Help Willix the Importer escape from Razorfen Kraul"]={pos={{11,0.4226,0.8987,100}}},
    ["Hit 20 braziers."]={pos={{36,0.5003,0.7224,100},{25,0.6502,0.2371,92},{1,0.4668,0.3813,70},{23,0.2105,0.2649,70},{45,0.6864,0.0803,65}}},
    ["Hit 8 braziers."]={pos={{36,0.5002,0.7222,100},{25,0.6504,0.2372,88},{24,0.5659,0.9207,83},{1,0.4667,0.3814,76},{45,0.6855,0.0787,73}}},
    ["Hold Five Bases."]={pos={{60,0.6851,0.5864,100}}},
    ["Hold Four Bases."]={pos={{39,0.7365,0.2944,100},{60,0.6728,0.5643,72},{45,0.6091,0.9175,29}}},
    ["Horgrenn Hellcleave defeated"]={pos={{69,0.2311,0.646,100}}},
    ["Hourglass of Eternity protected"]={pos={{68,0.7157,0.3891,100}}},
    ["Hourglass of Eternity protected from the Infinite Dragonflight."]={pos={{68,0.7174,0.3917,100}}},
    ["Illidan's Message Delivered"]={pos={{53,0.4646,0.7185,100}}},
    ["Illidan's Pupil"]={pos={{58,0.2735,0.4307,100}}},
    ["Information Gathered from Kharan"]={pos={{32,0.271,0.7254,100}}},
    ["Information Gathering"]={pos={{59,0.4819,0.8406,100}}},
    ["Investigate An'daroth"]={pos={{44,0.3715,0.1612,100}}},
    ["Investigate Cave in Boulderslide Ravine"]={pos={{6,0.5897,0.9012,100}}},
    ["Investigate a circle"]={pos={{43,0.6038,0.6167,100},{24,0.3644,0.5557,87},{37,0.3234,0.5398,75},{41,0.5795,0.5272,62},{7,0.4884,0.1736,56}}},
    ["Investigate the Amani Catacombs"]={pos={{44,0.629,0.3098,100}}},
    ["Investigate the Spawning Glen"]={pos={{57,0.1506,0.6123,100}}},
    ["Ironhide defeated"]={pos={{69,0.2302,0.6452,100}}},
    ["Ironhide defeated "]={pos={{69,0.232,0.6468,100}}},
    ["Jail Break!"]={pos={{32,0.271,0.7255,100},{40,0.2257,0.0757,46}}},
    ["Journal Entry Read"]={pos={{47,0.4658,0.7051,100},{47,0.4677,0.7452,91}}},
    ["Kalaran Story"]={pos={{32,0.3904,0.3895,100}}},
    ["Kaya Escorted to Camp Aparaje"]={pos={{6,0.7707,0.9085,100}}},
    ["Keep Piznik safe while he mines the mysterious ore"]={pos={{6,0.7178,0.602,100}}},
    ["Kernobee Rescue"]={pos={{28,0.1767,0.3914,100}}},
    ["Kharan's Tale"]={pos={{32,0.271,0.7254,100},{40,0.2257,0.0758,61}}},
    ["Khit'rix the Dark Master Defeated"]={pos={{71,0.3101,0.2919,100}}},
    ["Korrak the Bloodrager Defeated"]={pos={{75,0.4804,0.5675,100}}},
    ["Lakes of Zangarmarsh Explored"]={pos={{57,0.7724,0.4507,100}}},
    ["Launch to Ruuan Weald."]={pos={{54,0.6018,0.6863,100}}},
    ["Lead Mist safely to Sentinel Arynia Cloudsbreak"]={pos={{24,0.383,0.3439,100}}},
    ["Lead Tooga to Torta"]={pos={{8,0.6656,0.2564,100}}},
    ["Learn the purpose of the Stone Watcher of Norgannon"]={pos={{8,0.3766,0.814,100}}},
    ["Learn what lore that the stone watcher has to offer"]={pos={{27,0.3522,0.1033,100}}},
    ["Lebronski Bluffed"]={pos={{70,0.748,0.6528,100}}},
    ["Legion Gateway Destroyed"]={pos={{56,0.5851,0.1851,100}}},
    ["Letter from Saurfang read and destroyed"]={pos={{68,0.3731,0.4666,100}}},
    ["Light the Sacred Fire of Life"]={pos={{14,0.3807,0.3535,100}}},
    ["Listen to Greatmother Geyah"]={pos={{58,0.5666,0.3431,100}}},
    ["Listen to Lorax's Tale"]={pos={{19,0.6379,0.7375,100}}},
    ["Listen to the plan of the Twilight Cultists"]={pos={{2,0.0915,0.1241,100}}},
    ["Locate Missing Scout"]={pos={{73,0.383,0.772,100}}},
    ["Locate the haunted island"]={pos={{38,0.2157,0.2201,100}}},
    ["Locate the hunters' camp"]={pos={{38,0.3573,0.1084,100}}},
    ["Locate the large, red crystal on Darkshore's eastern mountain range"]={pos={{16,0.4726,0.4883,100}}},
    ["Loramus' Story"]={pos={{15,0.608,0.6636,100}}},
    ["Lord-Commander Arete's tale listened to."]={pos={{71,0.1956,0.4814,100}}},
    ["Magwin Escorted to Safety"]={pos={{3,0.1638,0.9414,100}}},
    ["Main building at the Altar of Sseratus investigated."]={pos={{75,0.4032,0.3946,100}}},
    ["Mana-Tombs Stasis Chamber Investigated"]={pos={{55,0.3964,0.5754,100}}},
    ["Master Kariel Winthalus Found"]={pos={{17,0.6286,0.249,100},{17,0.6032,0.3042,92}}},
    ["Master's Touch"]={pos={{8,0.5721,0.6295,100}}},
    ["Matis the Cruel Captured"]={pos={{9,0.254,0.5351,100},{9,0.2919,0.515,66},{9,0.3233,0.4826,58},{9,0.3675,0.4674,45},{9,0.403,0.4525,34}}},
    ["Meeting with Illidan Stormrage"]={pos={{53,0.6596,0.8615,100}}},
    ["Meeting with Kolphis Darkscale attended"]={pos={{54,0.326,0.3745,100}}},
    ["Message to the Wildhammer Delivered"]={pos={{42,0.1434,0.4806,100}}},Milked={pos={{40,0.651,0.2367,100}}},
    ["Millhouse Manastorm Rescued"]={pos={{59,0.7452,0.5766,100}}},
    ["Mogor, Hero of the Warmaul Defeated"]={pos={{58,0.4334,0.2069,100}}},
    ["Mootoo Saved"]={pos={{65,0.3119,0.5444,100}}},
    ["Murg \"Oldie\" Muckjaw Defeated"]={pos={{53,0.6475,0.8497,100}}},
    ["Murkblood Information Gathered"]={pos={{53,0.731,0.8227,100},{53,0.6936,0.8011,48}}},
    ["Name of the Magnataur Warlord"]={pos={{68,0.7256,0.4962,100}}},
    ["Negotiations with Overseer Nuaar complete"]={pos={{54,0.6,0.4037,100},{54,0.6193,0.3305,81},{54,0.6255,0.2969,54},{54,0.5904,0.3646,42}}},
    ["Oacha'noa's compulsion obeyed."]={pos={{68,0.3409,0.8401,100}}},
    ["Offer the sacrifice at the fountain"]={pos={{21,0.3865,0.8586,100}}},
    ["Omosh Dance of Joy Learned"]={pos={{1,0.7932,0.223,100}}},
    ["Orinoko Tuskbreaker Defeated"]={pos={{75,0.48,0.5672,100}}},
    ["Orphaned Mammoth Calf Delivered to Khu'nok"]={pos={{65,0.5935,0.3055,100}}},
    ["Overhear Lescovar and Marzon's Conversation"]={pos={{36,0.7276,0.3563,100}}},
    ["Overlook Hearthglen from a high vantage point"]={pos={{50,0.457,0.185,100}}},
    ["Pit of Narjun Explored"]={pos={{68,0.2626,0.5001,100}}},
    ["Place Dawn's Gambit"]={pos={{50,0.6902,0.728,100}}},
    ["Place the Toxic Fogger"]={pos={{6,0.6644,0.4545,100}}},
    ["Place the grim message."]={pos={{42,0.234,0.5805,100}}},
    ["Plainstrider Menace"]={pos={{11,0.5081,0.345,100}}},
    ["Plundering the Plunderers"]={pos={{11,0.6491,0.4539,100}}},
    ["Practical Prey"]={pos={{7,0.6447,0.8022,100}}},
    ["Prince Sandoval Defeated"]={pos={{71,0.3089,0.2932,100}}},
    ["Princess Stillpine Saved"]={pos={{9,0.6536,0.8072,100}}},
    ["Prisoner Transport"]={pos={{40,0.2579,0.2687,100}}},
    ["Proof Presented"]={pos={{40,0.9499,0.316,100}}},
    ["Protect A-Me 01 until you reach Karna Remtravel"]={pos={{18,0.4641,0.1376,100}}},
    ["Protect Apprentice Mirveda"]={pos={{41,0.5429,0.71,100}}},
    ["Protect Arko'narin out of Shadow Hold"]={pos={{13,0.3545,0.5908,100}}},
    ["Protect Aynasha"]={pos={{16,0.4584,0.9041,100}}},
    ["Protect Belnistrasz while he performs the ritual to shut down the idol"]={pos={{11,0.5086,0.9287,100}}},
    ["Protect Captain Vanessa Beltis from the naga attack"]={pos={{15,0.5276,0.8774,100}}},
    ["Protect Daphne Stilwell"]={pos={{49,0.4216,0.8845,100}}},
    ["Protect Feero Ironhand"]={pos={{16,0.4354,0.9438,100}}},
    ["Protect Kanati Greycloud"]={pos={{14,0.2137,0.3199,100}}},
    ["Protect Kinelory"]={pos={{39,0.6008,0.5384,100}}},
    ["Protect the Explorers"]={pos={{55,0.3012,0.709,100}}},
    ["Put Out the Fires"]={pos={{37,0.4231,0.6584,100},{43,0.613,0.5192,80},{28,0.4666,0.5202,32},{7,0.5238,0.4218,29}}},
    ["Question Reethe with Ogron"]={pos={{10,0.4248,0.3807,100}}},
    ["Quetz'lun's fate revealed."]={pos={{75,0.7575,0.5839,100}}},
    ["Ragged John's Story"]={pos={{40,0.6509,0.2367,100}}},
    ["Ram Collared and Returned"]={pos={{60,0.6722,0.3461,100},{36,0.8333,0.342,90},{25,0.7007,0.9013,57},{26,0.3464,0.7493,51},{21,0.5796,0.3659,23}}},
    ["Raptor Thieves"]={pos={{11,0.5453,0.3593,100}}},
    ["Reach the Sky's Limit."]={pos={{54,0.6025,0.6857,100}}},
    ["Receive Elune's Blessing."]={pos={{20,0.6431,0.6194,100},{20,0.6223,0.6551,35}}},
    ["Reconnaissance Flight"]={pos={{72,0.5004,0.6143,100}}},
    ["Redemption?"]={pos={{50,0.5391,0.2437,100}}},
    ["Reef Bull led to a Reef Cow"]={pos={{70,0.3116,0.7163,100}}},
    ["Reginald's March"]={pos={{36,0.7966,0.3878,100}}},
    ["Release Oben Rageclaw's spirit"]={pos={{24,0.4551,0.5862,100}}},
    ["Rescue Apothecary Hanes"]={pos={{70,0.7872,0.3723,100}}},
    ["Rescue Dalinda Malem"]={pos={{4,0.5825,0.3091,100}}},
    ["Rescue the Skyguard Prisoner."]={pos={{55,0.6977,0.7597,100},{55,0.624,0.7387,92},{55,0.7393,0.883,91}}},
    ["Return the corrupted cat to Winna Hazzard"]={pos={{13,0.3427,0.5232,100}}},
    ["Righteous Sermon Heard"]={pos={{68,0.7673,0.474,100}}},
    ["Rocket Jump Mastered"]={pos={{70,0.7508,0.6455,100}}},
    ["Rokdar the Sundered Lord Defeated"]={pos={{58,0.4338,0.2065,100}}},
    ["Ruse of the Ashtongue"]={pos={{59,0.7386,0.6376,100}}},
    ["Rustblood defeated"]={pos={{69,0.2312,0.6462,100}}},
    ["Sabatoge the Mistwhisper Weather Shrine"]={pos={{72,0.4533,0.3717,100}}},
    ["Sabotage the Mistwhisper Weather Shrine"]={pos={{72,0.4523,0.371,100}}},
    ["Sal'salabim Persuaded"]={pos={{60,0.768,0.3419,100}}},
    ["Salandria taken to Sporeggar"]={pos={{57,0.1921,0.5113,100}}},
    ["Salandria taken to the Caverns of Time"]={pos={{8,0.6053,0.5769,100}}},
    ["Salandria taken to the Dark Portal"]={pos={{56,0.884,0.5017,100}}},
    ["Salandria taken to the Throne of the Elements"]={pos={{58,0.6053,0.2271,100}}},
    ["Save at least 6 Sprite Darters from capture"]={pos={{17,0.6726,0.4684,100}}},
    ["Scourge Leader identified"]={pos={{65,0.3641,0.6352,100}}},
    ["Scout out the Forsaken's Wickerman Festival."]={pos={{43,0.5547,0.7009,100}}},
    ["Scout the gazebo on Mystral Lake that overlooks the nearby Alliance outpost."]={pos={{2,0.4892,0.696,100}}},
    ["Scout through the Fargodeep Mine"]={pos={{37,0.3998,0.8136,100}}},
    ["Scout through the Jasperlode Mine"]={pos={{37,0.6053,0.5017,100}}},
    ["Search for the Temple of Atal'Hakkar"]={pos={{46,0.6433,0.4998,100},{46,0.6404,0.5327,55},{46,0.648,0.574,44},{46,0.6547,0.4704,36},{46,0.6852,0.4433,35}}},
    ["Search the Altar of Zul"]={pos={{42,0.4885,0.6842,100}}},
    ["Second triangulation point discovered"]={pos={{59,0.2892,0.4125,100}}},
    ["Secret phrase found"]={pos={{14,0.7961,0.7564,100}}},
    ["Secrets of Nifflevar Uncovered"]={pos={{70,0.6904,0.5479,100}}},
    ["Secrets of Wyrmskull Uncovered"]={pos={{70,0.6013,0.508,100}}},
    ["Secure Passage to Dragonblight"]={pos={{68,0.1029,0.5383,100}}},
    ["Secure a Spirit Tower"]={pos={{55,0.4898,0.603,100},{55,0.4249,0.5398,74},{55,0.4722,0.7227,61},{55,0.3246,0.5786,50},{55,0.4047,0.7801,48}}},
    ["Seek out the Great Bear Spirit and learn what it has to share with you about the nature of the bear."]={pos={{20,0.3926,0.2773,100}}},
    ["Seize Control of an Eidolon Watcher"]={pos={{71,0.441,0.2469,100}}},
    ["Sentry Point explored"]={pos={{10,0.5977,0.4107,100}}},
    ["Shattered Salute Performed"]={pos={{1,0.4311,0.5348,100}}},
    ["Sigrid Iceborn Defeated"]={pos={{71,0.3058,0.2893,100}}},
    ["Singing crystal resonant frequency gauged"]={pos={{54,0.5988,0.7404,100}}},
    ["Siphon Bloodgem Crystal"]={pos={{59,0.2547,0.6659,100}}},
    ["Size Control of an Eidolon Watcher"]={pos={{71,0.441,0.2463,100}}},
    ["Skra'gath Defeated"]={pos={{58,0.4332,0.2072,100}}},
    ["Speak to Greatmother Geyah"]={pos={{58,0.5666,0.3431,100}}},
    ["Speak with someone in Ratchet about the Glowing Shard"]={pos={{11,0.6297,0.3721,100}}},
    ["Spiritual insight concerning Indu'le Village attained."]={pos={{68,0.4895,0.7584,100}}},
    ["Step on the grate to begin the Affray"]={pos={{11,0.6861,0.4872,100}}},
    ["Stillpine Furbolg Language Primer Read"]={pos={{3,0.4929,0.5105,100}}},
    ["Stinkbeard Defeated"]={pos={{75,0.4794,0.5661,100}}},
    ["Story of Thaurissan"]={pos={{25,0.3862,0.5544,100}}},
    ["Subdue Private Hendel"]={pos={{10,0.452,0.2449,100}}},
    ["Subdue Reth'hedron the Subduer"]={pos={{58,0.0876,0.4284,100}}},
    ["Successfully assisted Longrunner Proudhoof's assault."]={pos={{65,0.4945,0.2649,100}}},
    ["Sun Portal Site Confirmed"]={pos={{9,0.5257,0.2218,100}}},
    ["Survey Alcaz Island"]={pos={{10,0.6996,0.1955,100},{10,0.6736,0.5084,69}}},
    ["Survive the Onslaught"]={pos={{32,0.271,0.7254,100},{40,0.2256,0.0755,36}}},
    ["Take Shay Leafrunner to Rockbiter's camp"]={pos={{17,0.423,0.2182,100}}},
    ["Take Silverwing Outpost."]={pos={{2,0.6466,0.7535,100}}},
    ["Tame a Barbed Crawler"]={pos={{3,0.2036,0.6445,100},{3,0.2033,0.6873,32},{3,0.2194,0.7228,22}}},
    ["Tame a Crazed Dragonhawk"]={pos={{41,0.604,0.5921,100},{41,0.6125,0.652,23}}},
    ["Tame a Dire Mottled Boar"]={pos={{7,0.5161,0.4629,100}}},
    ["Tame a Greater Timberstrider"]={pos={{3,0.364,0.354,100},{3,0.3594,0.3066,31}}},
    ["Tame a Large Crag Boar"]={pos={{28,0.4834,0.5659,100},{28,0.4818,0.4738,25}}},
    ["Tame a Mistbat"]={pos={{44,0.4833,0.1359,100},{44,0.5518,0.1102,22}}},
    ["Tame a Nightsaber Stalker"]={pos={{24,0.4009,0.5546,100},{24,0.5582,0.721,96}}},
    ["Tame a Nightstalker"]={pos={{3,0.3645,0.4,100}}},
    ["Tame a Prairie Stalker"]={pos={{22,0.465,0.4936,100},{22,0.4369,0.5171,62},{22,0.5569,0.5728,20}}},
    ["Tame a Snow Leopard"]={pos={{28,0.4857,0.5929,100}}},
    ["Tame a Strigid Screecher"]={pos={{24,0.4378,0.5095,100}}},
    ["Tame a Surf Crawler"]={pos={{7,0.59,0.2922,100},{7,0.6139,0.7803,21}}},
    ["Tame a Swoop"]={pos={{22,0.4626,0.4947,100},{22,0.426,0.4886,74},{22,0.4773,0.4652,74},{22,0.4305,0.5223,66},{22,0.4581,0.4289,26}}},
    ["Tame a Webwood Lurker"]={pos={{24,0.5917,0.5823,100}}},
    ["Tame an Adult Plainstrider"]={pos={{22,0.5305,0.5755,100},{22,0.431,0.5314,48},{22,0.53,0.6132,47},{22,0.4352,0.4534,23}}},
    ["Tame an Armored Scorpid"]={pos={{7,0.4514,0.4549,100},{7,0.5507,0.378,22}}},
    ["Tame an Elder Springpaw"]={pos={{41,0.6189,0.6471,100},{41,0.6405,0.6133,27}}},
    ["Tame an Ice Claw Bear"]={pos={{28,0.4986,0.536,100},{28,0.5029,0.589,23},{28,0.371,0.4488,22}}},
    ["Tatjana Delivered"]={pos={{69,0.5777,0.417,100}}},
    ["Test Tally's Experiment"]={pos={{54,0.6011,0.6884,100}}},
    ["Test the Eggscilliscope Prototype"]={pos={{40,0.3299,0.2519,100},{32,0.4078,0.9569,90}}},
    ["Thane Banahogg Defeated"]={pos={{71,0.3078,0.2912,100}}},
    ["The Balance of Light and Shadow"]={pos={{34,0.1758,0.1362,100}}},
    ["The Blightcaller Uncovered"]={pos={{34,0.2378,0.6853,100}}},
    ["The Blue Brothers Defeated"]={pos={{58,0.4333,0.2069,100}}},
    ["The Cipher of Damnation - History and Truth"]={pos={{53,0.5391,0.2348,100}}},
    ["The Dark Portal Opened"]={pos={{8,0.5721,0.6294,100}}},
    ["The Forgotten Redeemed"]={pos={{68,0.8686,0.6618,100}}},
    ["The Horseman's Challenge"]={pos={{78,0.5241,0.3459,100}}},
    ["The Night Watch"]={pos={{31,0.8018,0.6583,100},{31,0.2226,0.3806,60}}},
    ["The Path of Conquest Discovered"]={pos={{53,0.5116,0.6277,100},{53,0.524,0.5902,53},{53,0.5354,0.675,21}}},
    ["The Redemption of Eranikus"]={pos={{20,0.5123,0.3835,100}}},
    ["The Shattered Hand"]={pos={{1,0.4986,0.704,100},{11,0.6437,0.4394,100}}},
    ["The Tale of Neltharaku"]={pos={{53,0.6617,0.5956,100},{53,0.6236,0.6027,72},{53,0.617,0.5495,69},{53,0.5933,0.5866,49},{53,0.6952,0.6154,45}}},
    ["The Tale of Sorrow"]={pos={{46,0.3427,0.6598,100}}},
    ["The War of the Shifting Sands"]={pos={{5,0.2895,0.9208,100}}},
    ["The Warmaul Champion Defeated"]={pos={{58,0.4343,0.2063,100}}},
    ["The Zhevra"]={pos={{11,0.4276,0.2625,100}}},
    ["Thel'zan the Duskbringer Defeated"]={pos={{68,0.8111,0.5064,100}}},
    ["Thrall's Tale"]={pos={{1,0.3184,0.3779,100}}},
    ["Throw caution to the wind."]={pos={{54,0.6033,0.6889,100}}},
    ["Thundering Cave investigated"]={pos={{70,0.715,0.6975,100}}},
    ["Tirion's Tale"]={pos={{34,0.0468,0.3841,100}}},
    ["Torch Creation"]={pos={{32,0.3899,0.3897,100}}},
    ["Torgg Thundertotem defeated"]={pos={{69,0.2305,0.6455,100}}},
    ["Travel to Mistwhisper Refuge."]={pos={{72,0.4631,0.3988,100}}},
    ["Travel to Mosswalker Village."]={pos={{72,0.7507,0.5188,100}}},
    ["Traverse Dun Algaz"]={pos={{51,0.5345,0.7036,100}}},
    ["Trope the Filth-Belcher Defeated"]={pos={{53,0.6475,0.8504,100}}},
    ["Try to find the Heart of the Storm before Overseer Narvir does"]={pos={{73,0.3607,0.6092,100}}},
    ["Umbrafen Lake Investigated"]={pos={{57,0.7094,0.8193,100},{57,0.7095,0.7881,96}}},
    ["Uncover the Magmawyrm Resurrection Chamber"]={pos={{68,0.3176,0.3046,100}}},
    ["Unkor Submits"]={pos={{55,0.2003,0.6302,100}}},
    ["Vanquish the Betrayers"]={pos={{7,0.5951,0.5828,100}}},
    ["Varidus the Flenser Defeated"]={pos={{65,0.3513,0.4632,100}}},
    ["Vector Coil Destroyed and Sironas Slain"]={pos={{9,0.1484,0.5482,100}}},
    ["Victory in Alterac Valley"]={pos={{60,0.6752,0.3456,100},{60,0.6669,0.5705,96},{36,0.8326,0.3435,57},{1,0.7909,0.3105,47},{25,0.7011,0.9027,28}}},
    ["Victory in Arathi Basin"]={pos={{60,0.6696,0.5668,100},{60,0.6721,0.3385,89},{36,0.8342,0.3448,67},{1,0.7928,0.3015,66},{25,0.7025,0.8964,38}}},
    ["Victory in Eye of the Storm"]={pos={{60,0.6718,0.5631,100},{1,0.7916,0.3028,54}}},
    ["Victory in Lake Wintergrasp"]={pos={{74,0.5029,0.1947,100},{74,0.4988,0.1572,59},{74,0.6755,0.3056,32}}},
    ["Victory in Strand of the Ancients"]={pos={{74,0.4909,0.1256,100},{1,0.5012,0.6877,60},{1,0.7112,0.3326,60},{67,0.3091,0.7542,60},{67,0.5642,0.3578,60}}},
    ["Victory in Warsong Gulch"]={pos={{60,0.6682,0.57,100},{60,0.675,0.346,92},{1,0.7918,0.307,76},{36,0.8354,0.3469,76},{25,0.7046,0.8946,40}}},
    ["Victory in the Eye of the Storm"]={pos={{60,0.6706,0.3382,100},{36,0.8351,0.3502,52},{25,0.7008,0.8987,27}}},
    ["Vision from the Past"]={pos={{35,0.4653,0.7618,100}}},
    ["Vladof the Butcher Defeated"]={pos={{75,0.4798,0.5674,100}}},
    ["Wait for Grimshade to finish"]={pos={{33,0.6699,0.1941,100}}},
    ["Wait for Menara Voidrender to complete your item"]={pos={{11,0.6252,0.3547,100}}},
    ["Waking Legends."]={pos={{20,0.4036,0.4796,100}}},
    ["Warsong Battle Standard Defended"]={pos={{68,0.2509,0.4197,100}}},
    ["Watch Trenton Work"]={pos={{8,0.5143,0.2871,100}}},
    ["Weapon Emblazoned"]={pos={{78,0.4836,0.2778,100},{78,0.4758,0.3075,27}}},
    ["Weapon emblazoned"]={pos={{78,0.485,0.281,100}}},
    ["Weaponry Creation"]={pos={{38,0.5062,0.2048,100}}},
    ["Wing Commander Ichman Defeated"]={pos={{53,0.6473,0.8494,100}}},
    ["Wing Commander Mulverick Defeated"]={pos={{53,0.6472,0.844,100}}},
    ["Witness the Reckoning"]={pos={{73,0.3464,0.339,100}}},
    ["Yggdras Defeated"]={pos={{75,0.4793,0.5685,100}}},
    ["You Are The Big Winner"]={pos={{38,0.5062,0.2048,100}}},
    ["You know, maybe we can become friends after all. Follow me; we don't want to have to share this with the others now, do we?"]={pos={{57,0.7858,0.6265,100}}},
    ["Zalazane"]={pos={{7,0.672,0.8758,100}}},
    ["Zamael Story"]={pos={{32,0.2959,0.2638,100}}},
}

-- QuestHelper mapID mapping
_WorldMapSize = {
    -- World Map of Azeroth
    [0] = {
        parentContinent = 0,
    },
    -- Kalimdor
    {
        parentContinent = 0,
        zoneData = {
            Ashenvale = {
                mapID = 331,
            },
            Aszhara = {
                mapID = 16,
            },
            AzuremystIsle = {
                mapID = 3524,
            },
            Barrens = {
                mapID = 17,
            },
            BloodmystIsle = {
                mapID = 3525,
            },
            Darkshore = {
                mapID = 148,
            },
            Darnassis = {
                mapID = 1657,
            },
            Desolace = {
                mapID = 405,
            },
            Durotar = {
                mapID = 14,
            },
            Dustwallow = {
                mapID = 15,
            },
            Felwood = {
                mapID = 361,
            },
            Feralas = {
                mapID = 357,
            },
            Moonglade = {
                mapID = 493,
            },
            Mulgore = {
                mapID = 215,
            },
            Ogrimmar = {
                mapID = 1637,
            },
            Silithus = {
                mapID = 1377,
            },
            StonetalonMountains = {
                mapID = 406,
            },
            Tanaris = {
                mapID = 440,
            },
            Teldrassil = {
                mapID = 141,
            },
            TheExodar = {
                mapID = 3557,
            },
            ThousandNeedles = {
                mapID = 400,
            },
            ThunderBluff = {
                mapID = 1638,
            },
            UngoroCrater = {
                mapID = 490,
            },
            Winterspring = {
                mapID = 618,
            },
        },
    },
    -- Eastern Kingdoms
    {
        parentContinent = 0,
        zoneData = {
            Alterac = {
                mapID = 2597,
            },
            Arathi = {
                mapID = 3358,
            },
            Badlands = {
                mapID = 3,
            },
            BlastedLands = {
                mapID = 4,
            },
            BurningSteppes = {
                mapID = 46,
            },
            DeadwindPass = {
                mapID = 41,
            },
            DunMorogh = {
                mapID = 1,
            },
            Duskwood = {
                mapID = 10,
            },
            EasternPlaguelands = {
                mapID = 139,
            },
            Elwynn = {
                mapID = 12,
            },
            EversongWoods = {
                mapID = 3430,
            },
            Ghostlands = {
                mapID = 3433,
            },
            Hilsbrad = {
                mapID = 267,
            },
            Hinterlands = {
                mapID = 47,
            },
            Ironforge = {
                mapID = 1537,
            },
            LochModan = {
                mapID = 38,
            },
            Redridge = {
                mapID = 44,
            },
            SearingGorge = {
                mapID = 51,
            },
            SilvermoonCity = {
                mapID = 3487,
            },
            Silverpine = {
                mapID = 130,
            },
            Stormwind = {
                mapID = 1519,
            },
            Stranglethorn = {
                mapID = 33,
            },
            Sunwell = {
                mapID = 4080,
            },
            SwampOfSorrows = {
                mapID = 8,
            },
            Tirisfal = {
                mapID = 85,
            },
            Undercity = {
                mapID = 1497,
            },
            WesternPlaguelands = {
                mapID = 28,
            },
            Westfall = {
                mapID = 40,
            },
            Wetlands = {
                mapID = 11,
            },
        },
    },
    -- Outland
    {
        parentContinent = 3,
        zoneData = {
            BladesEdgeMountains = {
                mapID = 3522,
            },
            Hellfire = {
                mapID = 3483,
            },
            Nagrand = {
                mapID = 3518,
            },
            Netherstorm = {
                mapID = 3523,
            },
            ShadowmoonValley = {
                mapID = 3520,
            },
            ShattrathCity = {
                mapID = 3703,
            },
            TerokkarForest = {
                mapID = 3519,
            },
            Zangarmarsh = {
                mapID = 3521,
            },
        },
    },
    [4] = {
        parentContinent = 0,
        zoneData = {
            BoreanTundra = {
                mapID = 3537,
            },
            CrystalsongForest = {
                mapID = 2817,
            },
            Dalaran = {
                mapID = 4395,
            },
            Dragonblight = {
                mapID = 65,
            },
            GrizzlyHills = {
                mapID = 394,
            },
            HowlingFjord = {
                mapID = 495,
            },
            IcecrownGlacier = {
                mapID = 210,
            },
            LakeWintergrasp = {
                mapID = 4197,
            },
            SholazarBasin = {
                mapID = 3711,
            },
            TheStormPeaks = {
                mapID = 67,
            },
            ZulDrak = {
                mapID = 66,
            },
            HrothgarsLanding = {
                height = 2452.7,
                width = 2452.7*1.5,
                xOffset = 23967.599 - 17549.182,
                yOffset = 1027.392 - 1215.431,
            }
        },
    }
}

-- QuestHelper zone lookup giving continentId + zoneId
_QuestHelper_ZoneLookup = {
    {1,14,},
    {1,1,},
    {1,3,},
    {1,7,},
    {1,15,},
    {1,16,},
    {1,8,},
    {1,17,},
    {1,4,},
    {1,9,},
    {1,19,},
    {1,20,},
    {1,10,},
    {1,21,},
    {1,2,},
    {1,5,},
    {1,11,},
    {1,23,},
    {1,24,},
    {1,12,},
    {1,6,},
    {1,13,},
    {1,22,},
    {1,18,},
    {2,14,},
    {2,1,},
    {2,3,},
    {2,7,},
    {2,16,},
    {2,17,},
    {2,8,},
    {2,18,},
    {2,4,},
    {2,9,},
    {2,20,},
    {2,21,},
    {2,10,},
    {2,22,},
    {2,2,},
    {2,5,},
    {2,11,},
    {2,24,},
    {2,25,},
    {2,12,},
    {2,26,},
    {2,23,},
    {2,6,},
    {2,13,},
    {2,28,},
    {2,27,},
    {2,29,},
    {2,19,},
    {3,5,},
    {3,1,},
    {3,7,},
    {3,2,},
    {3,8,},
    {3,3,},
    {3,4,},
    {3,6,},
    {1,0,},
    {2,0,},
    {3,0,},
    {2,15,},
    {4,1,},
    {4,2,},
    {4,3,},
    {4,4,},
    {4,5,},
    {4,6,},
    {4,8,},
    {4,9,},
    {4,10,},
    {4,11,},
    {4,12,},
    {4,0,},
    {-77,0,},
    {-77,1,},
    {-80,0,},
    {-80,1,},
    {-81,0,},
    {-81,1,},
    {-82,0,},
    {-82,1,},
    {-83,0,},
    {-83,1,},
    {-84,0,},
    {-84,1,},
    {-85,0,},
    {-85,1,},
    {-86,0,},
    {-86,1,},
    {-87,0,},
    {-87,1,},
    {-88,0,},
    {-88,1,},
    {-89,0,},
    {-89,1,},
    {-90,0,},
    {-90,1,},
    {-91,0,},
    {-91,1,},
    {-92,0,},
    {-92,1,},
    {-93,0,},
    {-93,1,},
    {-94,0,},
    {-94,1,},
    {-95,0,},
    {-95,1,},
    {-96,0,},
    {-96,1,},
    {-97,0,},
    {-97,1,},
    {-98,0,},
    {-98,1,},
    {-99,0,},
    {-99,1,},
    {-100,0,},
    {-100,1,},
    {-101,0,},
    {-101,1,},
    {-102,0,},
    {-102,1,},
    {-103,0,},
    {-103,1,},
    {-104,0,},
    {-104,1,},
    {-105,0,},
    {-105,1,},
    {-106,0,},
    {-106,1,},
    {-107,0,},
    {-107,1,},
    {-108,0,},
    {-108,1,},
    {-109,0,},
    {-109,1,},
    {-110,0,},
    {-110,1,},
    {-111,0,},
    {-111,1,},
    {-112,0,},
    {-112,1,},
    {-113,0,},
    {-113,1,},
    {-114,0,},
    {-114,1,},
    {-115,0,},
    {-115,1,},
    {-116,0,},
    {-116,1,},
    {4,7,},
    {-117,0,},
    {-117,1,},
    {-118,0,},
    {-118,1,},
}

-- All Questie questIds which are in the Wotlk database but not in the Tbc one
_DISTINCT_IDS = {
24584,
24648,
24712,
14437,
24840,
25480,
11238,
11270,
11302,
11366,
11398,
11430,
11494,
11590,
11622,
11654,
11686,
11718,
11878,
11910,
11942,
12006,
12038,
12070,
12102,
12134,
12166,
12198,
12230,
12262,
12294,
12326,
12358,
12390,
12422,
12454,
12486,
12518,
12550,
12582,
12614,
12646,
12678,
12710,
12742,
12774,
12806,
12838,
12870,
12902,
12934,
12966,
12998,
13030,
13062,
13094,
13126,
13158,
13190,
13222,
13254,
13286,
13318,
13350,
13382,
13414,
13446,
13478,
13606,
13670,
13702,
13734,
13830,
13862,
13926,
13990,
14022,
14054,
14086,
14150,
14182,
24522,
24586,
24650,
14438,
24842,
25482,
11175,
11239,
11271,
11303,
11367,
11399,
11495,
11527,
11559,
11591,
11623,
11655,
11687,
11719,
11879,
11911,
11943,
12007,
12039,
12071,
12103,
12135,
12167,
12199,
12231,
12263,
12295,
12327,
12359,
12391,
12423,
12455,
12487,
12519,
12551,
12583,
12615,
12647,
12679,
12711,
12743,
12775,
12807,
12839,
12871,
12903,
12935,
12967,
12999,
13031,
13063,
13095,
13127,
13159,
13191,
13223,
13255,
13287,
13319,
13351,
13383,
13415,
13447,
13479,
13607,
13671,
13703,
13735,
13767,
13863,
13927,
13959,
14023,
14055,
14087,
14119,
14151,
14183,
24588,
24652,
14439,
10376,
25484,
11176,
11240,
11272,
11304,
11432,
11464,
11560,
11592,
11624,
11656,
11688,
11720,
11912,
11944,
12008,
12040,
12072,
12104,
12136,
12168,
12200,
12232,
12264,
12296,
12328,
12360,
12392,
12424,
12456,
12488,
12520,
12552,
12584,
12616,
12648,
12680,
12712,
12744,
12776,
12808,
12840,
12872,
12904,
12936,
12968,
13000,
13032,
13064,
13096,
13128,
13160,
13192,
13224,
13256,
13288,
13320,
13352,
13384,
13416,
13448,
13480,
13672,
13704,
13736,
13768,
13832,
13864,
13960,
14024,
14088,
14152,
24590,
14440,
24846,
11241,
11273,
11305,
11433,
11465,
11529,
11561,
11593,
11625,
11689,
11721,
11881,
11913,
11945,
11977,
12009,
12041,
12073,
12105,
12137,
12169,
12201,
12233,
12265,
12297,
12329,
12361,
12393,
12425,
12457,
12489,
12521,
12553,
12585,
12617,
12649,
12681,
12713,
12745,
12777,
12809,
12841,
12873,
12905,
12937,
12969,
13001,
13033,
13065,
13097,
13129,
13161,
13193,
13225,
13257,
13289,
13321,
13353,
13385,
13417,
13449,
13481,
13609,
13641,
13673,
13705,
13737,
13769,
13833,
13929,
14089,
14185,
24656,
14409,
14441,
10378,
24912,
11274,
11306,
11402,
11434,
11466,
11530,
11562,
11594,
11626,
11658,
11690,
11722,
11914,
11946,
11978,
12010,
12042,
12074,
12106,
12138,
12170,
12202,
12234,
12266,
12298,
12330,
12362,
12394,
12426,
12458,
12490,
12522,
12554,
12586,
12618,
12650,
12682,
12714,
12746,
12778,
12810,
12842,
12874,
12906,
12938,
12970,
13002,
13034,
13066,
13098,
13130,
13162,
13194,
13226,
13258,
13290,
13322,
13354,
13386,
13418,
13450,
13482,
13610,
13674,
13706,
13738,
13770,
13834,
13930,
14058,
14090,
14186,
24594,
24658,
24850,
24914,
11179,
11243,
11275,
11307,
11467,
11563,
11595,
11627,
11659,
11723,
11979,
12011,
12043,
12075,
12107,
12139,
12171,
12203,
12235,
12267,
12299,
12331,
12363,
12395,
12427,
12459,
12523,
12555,
12587,
12619,
12651,
12683,
12715,
12747,
12779,
12811,
12843,
12875,
12907,
12939,
12971,
13003,
13035,
13067,
13099,
13131,
13163,
13195,
13227,
13259,
13291,
13323,
13355,
13387,
13419,
13451,
13483,
13611,
13643,
13675,
13707,
13739,
13771,
13835,
13931,
14059,
14187,
24596,
24660,
14443,
24916,
11116,
11244,
11276,
7702,
11436,
11468,
11564,
11596,
11628,
11660,
11692,
11724,
11788,
11884,
11916,
11980,
12044,
12076,
12108,
12140,
12172,
12204,
12236,
12268,
12300,
12332,
12364,
12396,
12428,
12460,
12524,
12556,
12588,
12620,
12652,
12684,
12716,
12748,
12780,
12812,
12844,
12876,
12908,
12940,
12972,
13004,
13036,
13068,
13100,
13132,
13164,
13196,
13228,
13260,
13292,
13324,
13356,
13388,
13420,
13452,
13484,
13548,
13676,
13708,
13740,
13772,
13836,
13932,
14028,
14060,
14092,
20439,
24598,
24662,
14444,
24918,
25238,
11245,
11277,
11309,
11469,
11501,
11565,
11597,
11629,
11661,
11693,
11725,
11789,
11949,
11981,
12013,
12045,
12077,
12109,
12141,
12173,
12205,
12237,
12269,
12301,
12333,
12365,
12397,
12429,
12461,
12493,
12525,
12557,
12589,
12621,
12653,
12685,
12717,
12749,
12781,
12813,
12845,
12877,
12909,
12941,
12973,
13005,
13037,
13069,
13101,
13133,
13165,
13197,
13229,
13261,
13293,
13325,
13357,
13389,
13421,
13453,
13485,
13549,
13677,
13709,
13741,
13773,
13837,
13933,
13997,
14061,
24216,
24536,
14349,
24664,
24792,
25240,
11182,
11246,
11278,
11310,
11406,
11470,
11566,
11598,
11630,
11662,
11694,
11726,
11790,
11918,
11950,
11982,
12014,
12046,
12078,
12110,
12142,
12174,
12206,
12238,
12270,
12302,
12334,
12366,
12398,
12430,
12462,
12494,
12526,
12558,
12590,
12622,
12654,
12686,
12718,
12750,
12782,
12814,
12846,
12878,
12910,
12942,
12974,
13006,
13038,
13070,
13102,
13134,
13166,
13198,
13230,
13262,
13294,
13326,
13358,
13390,
13422,
13454,
13486,
13614,
13678,
13710,
13742,
13774,
13838,
13934,
13966,
14030,
14062,
24218,
14350,
24666,
24922,
25242,
25306,
11247,
11279,
11311,
11343,
11471,
11567,
11599,
11631,
11663,
11695,
11727,
11791,
11887,
11919,
11951,
11983,
12015,
12047,
12079,
12111,
12143,
12175,
12207,
12239,
12271,
12303,
12335,
12367,
12399,
12431,
12463,
12495,
12527,
12559,
12591,
12623,
12655,
12687,
12719,
12751,
12783,
12815,
12847,
12879,
12911,
12943,
12975,
13007,
13039,
13071,
13103,
13135,
13167,
13199,
13231,
13263,
13295,
13327,
13359,
13391,
13423,
13455,
13487,
13679,
13711,
13743,
13775,
13807,
13839,
13903,
14095,
24220,
24476,
14351,
24796,
25500,
26012,
11248,
11280,
11312,
11344,
11472,
11504,
11568,
11600,
11632,
11664,
11728,
11792,
11888,
11920,
11984,
12016,
12048,
12080,
12112,
12144,
12176,
12208,
12240,
12272,
12304,
12336,
12368,
12400,
12432,
12464,
12496,
12528,
12560,
12592,
12624,
12656,
12688,
12720,
12752,
12784,
12816,
12848,
12880,
12912,
12944,
12976,
13008,
13040,
13072,
13104,
13136,
13168,
13200,
13232,
13264,
13296,
13328,
13360,
13392,
13424,
13456,
13488,
13616,
13680,
13744,
13776,
13904,
14032,
14064,
14096,
14160,
14352,
24798,
25246,
11153,
11249,
11281,
11313,
11473,
11569,
11601,
11633,
11697,
11729,
11793,
11889,
11985,
12017,
12049,
12081,
12113,
12145,
12177,
12209,
12241,
12273,
12305,
12337,
12369,
12401,
12433,
12465,
12497,
12529,
12561,
12593,
12625,
12657,
12689,
12721,
12753,
12785,
12817,
12849,
12881,
12913,
12945,
12977,
13009,
13041,
13073,
13105,
13137,
13169,
13201,
13233,
13265,
13297,
13329,
13361,
13393,
13425,
13457,
13489,
13649,
13681,
13713,
13745,
13777,
13809,
13905,
13937,
14033,
14065,
24224,
24480,
14353,
24800,
25248,
11154,
11218,
11250,
11282,
11314,
11346,
11410,
11474,
11570,
11602,
11634,
11698,
11730,
11794,
11890,
11986,
12050,
12082,
12114,
12146,
12178,
12210,
12242,
12274,
24609,
12338,
12370,
12402,
12434,
12466,
12498,
12530,
12562,
12594,
25249,
12658,
12690,
12722,
12754,
12786,
12818,
12850,
12882,
12914,
12946,
12978,
13010,
13042,
13074,
13106,
13138,
13170,
13202,
13234,
13266,
13298,
13330,
13362,
13394,
13426,
13458,
13490,
13682,
13714,
13746,
13778,
13810,
13906,
13938,
24226,
24610,
14418,
24802,
11155,
11187,
11251,
11283,
11315,
11411,
11443,
11475,
11507,
11571,
11603,
11635,
11699,
11795,
12019,
12051,
12083,
12115,
12147,
12179,
12211,
12243,
12275,
12307,
12339,
12371,
12403,
12435,
12467,
12499,
12531,
12563,
12595,
12627,
12659,
12691,
12723,
12755,
12787,
12819,
12851,
12883,
12915,
12947,
12979,
13011,
13043,
13075,
13107,
13139,
13171,
13203,
13235,
13267,
13299,
13331,
13363,
13395,
13427,
13459,
13491,
13715,
13747,
13779,
13811,
13843,
14035,
14163,
24548,
14355,
14419,
24804,
14483,
25444,
236,
11188,
11252,
11284,
11316,
11348,
11476,
11508,
11572,
11604,
11636,
11700,
11796,
11892,
11956,
11988,
12052,
12084,
12116,
12148,
12180,
12212,
12244,
12276,
12308,
12340,
12372,
12404,
12436,
12468,
12500,
12532,
12564,
12596,
12628,
12660,
12692,
12724,
12756,
12788,
12820,
12852,
12884,
12916,
12948,
12980,
13012,
13044,
13076,
13108,
13140,
13172,
13204,
13236,
13268,
13300,
13332,
13364,
13396,
13428,
13460,
13492,
13524,
13556,
13684,
13716,
13748,
13780,
13812,
13908,
14036,
14100,
14164,
14356,
14420,
24806,
24870,
25446,
11157,
11189,
11221,
11253,
11285,
5659,
11349,
11477,
11509,
11573,
11605,
11637,
11701,
11733,
11797,
11893,
11957,
11989,
12021,
12053,
12085,
12117,
12149,
12181,
12213,
12245,
12277,
12309,
12341,
12373,
12405,
12437,
12469,
12501,
12533,
12565,
12597,
12629,
12661,
12693,
12725,
12757,
12789,
12821,
12853,
12885,
12917,
12949,
12981,
13013,
13045,
13077,
13109,
13141,
13173,
13205,
13237,
13269,
13301,
13333,
13365,
13397,
13429,
13461,
13493,
13685,
13717,
13749,
13781,
13813,
13845,
14037,
14101,
14421,
24808,
24872,
11190,
11254,
11286,
11350,
11414,
11478,
11510,
11574,
11606,
11638,
11670,
11702,
11798,
11894,
11958,
11990,
12054,
12086,
12118,
12150,
12182,
12214,
12246,
24553,
12310,
12342,
12374,
12406,
12438,
12470,
12502,
12534,
12566,
12598,
12630,
12662,
12694,
12726,
12758,
12790,
12822,
12854,
12886,
12918,
12950,
12982,
13014,
13046,
13078,
13110,
13142,
13174,
13206,
13238,
13270,
13302,
13334,
13366,
13398,
13430,
13462,
13494,
13622,
13654,
13686,
13718,
13750,
13782,
13814,
13846,
14102,
14166,
24426,
24554,
24682,
24810,
24874,
11255,
11287,
11319,
11351,
11415,
11479,
11511,
11575,
11607,
11639,
11671,
11703,
11895,
11927,
11959,
11991,
12023,
12055,
12087,
12119,
12151,
12183,
12215,
12247,
12279,
12311,
12343,
12375,
12407,
12439,
12471,
12503,
12535,
12567,
12599,
12631,
12663,
12695,
12727,
12759,
12791,
12823,
12855,
12887,
12919,
12951,
12983,
13015,
13047,
13079,
13111,
13143,
13175,
13207,
13239,
13271,
13335,
13367,
13399,
13431,
13463,
13495,
13559,
13687,
13719,
13783,
13847,
14103,
14167,
14199,
24428,
24556,
24748,
24876,
11224,
11256,
11288,
11352,
11416,
11448,
11480,
11512,
11576,
11608,
11640,
11672,
11704,
11864,
11896,
11928,
11960,
12056,
12088,
12120,
12152,
12184,
12216,
12248,
12280,
12312,
12344,
12376,
12408,
12440,
12472,
12504,
12536,
12568,
12600,
12632,
12664,
12696,
12728,
12760,
12792,
12824,
12856,
12888,
12920,
12952,
12984,
13016,
13048,
13080,
13112,
13144,
13176,
13240,
13272,
13304,
13336,
13368,
13400,
13432,
13464,
13496,
13592,
13688,
13720,
13752,
13784,
13816,
14040,
14104,
14136,
14168,
14200,
24558,
14488,
11257,
11289,
11417,
11609,
11641,
11673,
11705,
11865,
11897,
11929,
11961,
11993,
12057,
12089,
12121,
12153,
12185,
12217,
12249,
12281,
12313,
12345,
12377,
12409,
12441,
12473,
12505,
12537,
12569,
12601,
12633,
12665,
12697,
12729,
12761,
12793,
12825,
12857,
12889,
12921,
12953,
12985,
13017,
13049,
13081,
13113,
13145,
13177,
13241,
13273,
13305,
13337,
13369,
13401,
13433,
13465,
13497,
13593,
13625,
13689,
13721,
13753,
13785,
13817,
14041,
14105,
14169,
24560,
14457,
24880,
11258,
11290,
11322,
11418,
11578,
11610,
11642,
11674,
11706,
11866,
11898,
11930,
11962,
11994,
12026,
12058,
12090,
12122,
12154,
12186,
12218,
12250,
12282,
12314,
12346,
12378,
12410,
12442,
12474,
12506,
12538,
12570,
12602,
12634,
12666,
12698,
12730,
12762,
12794,
12826,
12858,
12890,
12922,
12954,
12986,
13018,
13050,
13082,
13114,
13146,
13178,
13210,
13242,
13274,
13306,
13338,
13370,
13402,
13434,
13466,
13498,
13690,
13722,
13754,
13786,
13818,
13850,
13914,
14074,
14106,
14170,
24498,
24562,
24882,
26034,
11227,
11259,
11291,
11323,
11355,
11483,
11579,
11611,
11643,
11675,
11707,
11867,
11899,
11931,
11963,
11995,
12027,
12059,
12091,
12123,
12155,
12187,
12219,
12251,
12283,
12315,
12347,
12379,
12411,
12443,
12475,
12507,
12539,
12571,
12603,
12635,
12667,
12699,
12763,
12795,
12827,
12859,
12891,
12955,
12987,
13019,
13051,
13083,
13115,
13147,
13179,
13211,
13243,
13275,
13307,
13339,
13371,
13403,
13435,
13467,
13499,
13627,
13691,
13723,
13755,
13787,
13819,
13851,
13915,
14043,
14107,
14171,
14203,
24500,
24564,
24756,
24820,
24884,
11228,
11260,
11292,
11324,
11420,
11452,
11484,
11612,
11644,
11676,
11708,
11868,
11900,
11932,
11996,
12028,
12060,
12092,
12124,
12156,
12188,
12220,
12252,
12284,
12316,
12348,
12380,
12412,
12444,
12476,
12508,
12540,
12572,
12604,
12636,
12668,
12700,
12732,
12764,
12796,
12828,
12860,
12892,
12924,
12956,
12988,
13020,
13052,
13084,
13116,
13148,
13180,
13212,
13244,
13276,
13308,
13340,
13372,
13404,
13436,
13468,
13500,
13692,
13724,
13756,
13788,
13820,
13852,
13916,
14044,
14076,
14108,
14140,
14172,
24822,
24886,
11229,
11261,
11325,
11421,
11453,
11485,
11613,
11645,
11677,
11709,
11869,
11901,
11965,
11997,
12029,
12061,
12093,
12125,
12157,
12189,
12221,
12253,
12285,
12317,
12349,
12381,
12413,
24887,
12477,
12509,
12541,
12573,
12605,
12637,
12669,
12701,
12733,
12765,
12797,
12829,
12861,
12893,
12925,
12957,
12989,
13021,
13053,
13085,
13117,
13149,
13181,
13213,
13245,
13277,
13309,
13341,
13373,
13405,
13437,
13469,
13501,
13629,
13693,
13725,
13757,
13789,
13821,
13917,
14077,
14141,
14173,
24888,
11230,
11262,
11326,
11358,
11390,
11422,
11582,
11614,
11646,
11678,
11710,
11870,
11902,
11998,
12030,
12094,
12126,
12158,
12190,
12222,
12254,
12286,
12350,
12382,
12414,
12446,
12478,
12510,
12542,
12574,
12606,
12638,
12670,
12702,
12734,
12766,
12798,
12830,
12862,
12894,
12926,
12958,
12990,
13022,
13054,
13086,
13118,
13150,
13182,
13214,
13246,
13278,
13310,
13342,
13374,
13406,
13438,
13470,
13502,
13662,
13694,
13726,
13758,
13790,
13822,
13854,
13950,
14142,
14174,
24442,
24506,
24826,
24890,
11167,
11199,
11231,
11263,
11295,
11327,
11359,
11391,
11423,
11455,
11519,
11551,
11615,
11647,
11679,
11711,
11871,
11903,
11967,
11999,
12031,
12063,
12095,
12127,
12159,
12223,
12255,
12287,
12319,
12351,
12383,
12415,
12447,
12479,
12511,
12543,
12575,
12607,
12639,
12671,
12703,
12735,
12767,
12799,
12831,
12863,
12895,
12927,
12959,
12991,
13023,
13055,
13087,
13119,
13151,
13183,
13215,
13247,
13279,
13311,
13343,
13375,
13407,
13439,
13471,
13503,
13631,
13663,
13695,
13727,
13759,
13791,
13823,
13855,
13887,
13951,
14047,
14079,
14111,
14143,
14175,
24508,
24636,
24828,
24892,
25212,
11168,
11232,
11264,
11296,
11328,
11424,
11456,
11552,
11616,
11648,
11680,
11712,
11872,
11904,
11936,
11968,
12000,
12032,
12064,
12096,
12128,
12160,
12192,
12224,
12256,
12288,
12320,
12352,
12384,
12416,
12448,
12480,
12512,
12544,
12576,
12608,
12640,
12672,
12704,
12736,
12768,
12800,
12832,
12864,
12896,
12928,
12960,
12992,
13024,
13056,
13088,
13120,
13152,
13184,
13216,
13248,
13280,
13312,
13344,
13376,
13408,
13440,
13472,
13600,
13664,
13696,
13728,
13760,
13824,
13856,
13952,
14016,
14048,
14080,
14112,
14144,
14176,
24510,
24638,
24830,
24894,
25470,
11233,
11265,
11297,
11329,
11393,
11457,
11489,
11553,
11585,
11617,
11649,
11681,
11713,
11873,
11905,
11969,
12033,
12065,
12097,
12129,
12161,
12225,
12257,
12289,
12321,
12353,
12385,
12417,
12449,
12481,
12545,
12577,
12609,
12641,
12673,
12705,
12737,
12769,
12801,
12833,
12865,
12897,
12929,
12961,
12993,
13025,
13057,
13089,
13121,
13153,
13185,
13217,
13249,
13281,
13313,
13345,
13377,
13409,
13441,
13473,
13633,
13665,
13697,
13729,
13761,
13793,
13825,
13857,
13889,
14017,
14081,
14145,
14177,
24576,
24832,
24896,
11170,
11202,
11234,
11266,
11298,
11330,
11394,
11426,
11458,
11586,
11618,
11650,
11682,
11714,
11906,
11938,
12002,
12034,
12066,
12098,
12130,
12162,
12226,
12258,
12290,
12354,
12386,
12418,
12450,
12482,
12514,
12546,
12578,
12610,
12642,
12674,
12706,
12738,
12770,
12802,
12834,
12866,
12898,
12930,
12962,
12994,
13026,
13058,
13090,
13122,
13154,
13186,
13218,
13250,
13282,
13314,
13346,
13378,
13410,
13442,
13474,
13538,
13634,
13666,
13762,
13794,
13826,
13858,
13954,
13986,
14082,
14178,
24834,
26013,
25495,
25485,
25483,
11235,
11267,
11299,
11331,
25461,
11395,
11427,
11459,
11491,
25445,
25393,
11587,
11619,
11651,
11683,
11715,
25295,
25293,
25289,
25287,
24629,
11907,
11939,
25285,
12003,
12035,
12067,
12099,
12131,
12163,
12195,
12227,
12259,
12291,
12323,
12355,
12387,
12419,
12451,
12483,
25283,
12547,
12579,
12611,
12643,
12675,
12707,
12739,
12771,
12803,
12835,
12867,
12899,
12931,
12963,
12995,
13027,
13059,
13091,
13123,
13155,
13187,
13219,
13251,
13283,
13315,
13347,
13379,
13411,
13443,
13475,
25247,
13539,
13571,
13603,
25239,
13667,
13699,
13731,
13763,
13795,
25229,
13859,
25199,
24923,
13955,
24919,
24917,
14051,
14083,
24915,
14147,
14179,
24895,
24893,
24891,
24889,
24580,
24885,
24883,
24881,
24836,
24879,
24878,
24877,
24875,
24873,
24871,
24869,
24857,
24851,
24849,
24848,
24847,
24845,
24844,
24843,
24841,
24839,
24657,
24837,
24835,
24833,
24831,
24829,
24827,
24825,
24823,
11236,
11268,
11300,
11332,
24821,
11396,
11428,
11460,
24819,
24815,
24811,
24809,
11620,
11652,
11684,
11716,
24805,
24803,
24801,
24799,
11876,
11908,
11940,
24795,
12004,
12036,
12068,
12100,
12132,
12164,
12196,
12228,
12260,
12292,
12324,
12356,
12388,
12420,
12452,
12484,
12516,
12548,
12580,
12612,
12644,
12676,
12708,
12740,
12772,
12804,
12836,
12868,
12900,
12932,
12964,
12996,
13028,
13060,
13092,
13124,
13156,
13188,
13220,
13252,
13284,
13316,
13348,
13380,
13412,
13444,
13476,
24793,
24791,
24790,
13604,
24789,
13668,
13700,
13732,
13764,
24788,
13828,
13860,
24757,
24749,
13956,
24745,
24743,
24713,
14084,
24711,
14148,
14180,
24659,
24683,
24454,
24665,
24582,
24663,
24710,
14436,
24838,
24655,
24651,
24649,
24647,
24645,
24635,
25286,
24615,
24614,
24613,
24612,
24611,
24597,
24595,
24589,
24587,
24585,
24583,
24581,
24579,
24563,
24561,
24559,
24557,
24555,
24549,
11237,
11269,
11301,
11333,
11365,
11397,
11429,
11461,
24547,
24545,
24541,
24535,
11621,
11653,
11685,
11717,
24511,
24509,
24507,
24499,
24461,
11909,
11941,
11973,
12005,
12037,
12069,
12101,
12133,
12165,
12197,
12229,
12261,
12293,
12325,
12357,
12389,
12421,
12453,
12485,
12517,
12549,
12581,
12613,
12645,
12677,
12709,
12741,
12773,
12805,
12837,
12869,
12901,
12933,
12965,
12997,
13029,
13061,
13093,
13125,
13157,
13189,
13221,
13253,
13285,
13317,
13349,
13381,
13413,
13445,
13477,
24451,
24431,
24429,
24427,
24225,
13669,
13701,
13733,
13765,
24223,
13829,
13861,
24221,
24219,
13957,
24217,
20438,
14053,
14085,
11308,
14149,
14181,
5640,
7704,
11317,
5678,
}

-- QuestHelper zone mapping
_QuestHelper_Zones = {
    {[0]="Kalimdor",
   [1]="Ashenvale",
   [2]="Azshara",
   [3]="Azuremyst Isle",
   [4]="Bloodmyst Isle",
   [5]="Darkshore",
   [6]="Darnassus",
   [7]="Desolace",
   [8]="Durotar",
   [9]="Dustwallow Marsh",
   [10]="Felwood",
   [11]="Feralas",
   [12]="Moonglade",
   [13]="Mulgore",
   [14]="Orgrimmar",
   [15]="Silithus",
   [16]="Stonetalon Mountains",
   [17]="Tanaris",
   [18]="Teldrassil",
   [19]="The Barrens",
   [20]="The Exodar",
   [21]="Thousand Needles",
   [22]="Thunder Bluff",
   [23]="Un'Goro Crater",
   [24]="Winterspring"},
  {[0]="Eastern Kingdoms",
   [1]="Alterac Mountains",
   [2]="Arathi Highlands",
   [3]="Badlands",
   [4]="Blasted Lands",
   [5]="Burning Steppes",
   [6]="Deadwind Pass",
   [7]="Dun Morogh",
   [8]="Duskwood",
   [9]="Eastern Plaguelands",
   [10]="Elwynn Forest",
   [11]="Eversong Woods",
   [12]="Ghostlands",
   [13]="Hillsbrad Foothills",
   [14]="Ironforge",
   [15]="Isle of Quel'Danas",
   [16]="Loch Modan",
   [17]="Redridge Mountains",
   [18]="Searing Gorge",
   [19]="Silvermoon City",
   [20]="Silverpine Forest",
   [21]="Stormwind City",
   [22]="Stranglethorn Vale",
   [23]="Swamp of Sorrows",
   [24]="The Hinterlands",
   [25]="Tirisfal Glades",
   [26]="Undercity",
   [27]="Western Plaguelands",
   [28]="Westfall",
   [29]="Wetlands"},
  {[0]="Outland",
   [1]="Blade's Edge Mountains",
   [2]="Hellfire Peninsula",
   [3]="Nagrand",
   [4]="Netherstorm",
   [5]="Shadowmoon Valley",
   [6]="Shattrath City",
   [7]="Terokkar Forest",
   [8]="Zangarmarsh"},
  {[0]="Northrend",
   [1]="Borean Tundra",
   [2]="Crystalsong Forest",
   [3]="Dalaran",
   [4]="Dragonblight",
   [5]="Grizzly Hills",
   [6]="Howling Fjord",
   [7]="Icecrown",
   [8]="Sholazar Basin",
   [9]="The Storm Peaks",
   [10]="Wintergrasp",
   [11]="Zul'Drak",
   [12]="Zul'Drak"},

  [-77]={[0]="ScarletEnclave_Continent", [1]="ScarletEnclave"},

  [-80]={[0]="UtgardeKeep1_Continent", [1]="UtgardeKeep1"},
  [-81]={[0]="UtgardeKeep2_Continent", [1]="UtgardeKeep2"},
  [-82]={[0]="UtgardeKeep3_Continent", [1]="UtgardeKeep3"},

  [-83]={[0]="TheNexus_Continent", [1]="TheNexus"},

  [-84]={[0]="AzjolNerub1_Continent", [1]="AzjolNerub1"},
  [-85]={[0]="AzjolNerub2_Continent", [1]="AzjolNerub2"},
  [-86]={[0]="AzjolNerub3_Continent", [1]="AzjolNerub3"},

  [-87]={[0]="Ahnkahet_Continent", [1]="Ahnkahet"},

  [-88]={[0]="DrakTharonKeep1_Continent", [1]="DrakTharonKeep1"},
  [-89]={[0]="DrakTharonKeep2_Continent", [1]="DrakTharonKeep2"},

  [-90]={[0]="VioletHold_Continent", [1]="VioletHold"},

  [-91]={[0]="Gundrak_Continent", [1]="Gundrak"},

  [-92]={[0]="Ulduar77_Continent", [1]="Ulduar77"},

  [-93]={[0]="HallsofLightning1_Continent", [1]="HallsofLightning1"},
  [-94]={[0]="HallsofLightning2_Continent", [1]="HallsofLightning2"},

  [-95]={[0]="Nexus801_Continent", [1]="Nexus801"},
  [-96]={[0]="Nexus802_Continent", [1]="Nexus802"},
  [-97]={[0]="Nexus803_Continent", [1]="Nexus803"},
  [-98]={[0]="Nexus804_Continent", [1]="Nexus804"},

  [-99]={[0]="CoTStratholme1_Continent", [1]="CoTStratholme1"},
  [-100]={[0]="CoTStratholme2_Continent", [1]="CoTStratholme2"},

  [-101]={[0]="UtgardePinnacle1_Continent", [1]="UtgardePinnacle1"},
  [-102]={[0]="UtgardePinnacle2_Continent", [1]="UtgardePinnacle2"},

  [-103]={[0]="VaultofArchavon_Continent", [1]="VaultofArchavon"},

  [-104]={[0]="Naxxramas1_Continent", [1]="Naxxramas1"},
  [-105]={[0]="Naxxramas2_Continent", [1]="Naxxramas2"},
  [-106]={[0]="Naxxramas3_Continent", [1]="Naxxramas3"},
  [-107]={[0]="Naxxramas4_Continent", [1]="Naxxramas4"},
  [-108]={[0]="Naxxramas5_Continent", [1]="Naxxramas5"},
  [-109]={[0]="Naxxramas6_Continent", [1]="Naxxramas6"},

  [-110]={[0]="TheObsidianSanctum_Continent", [1]="TheObsidianSanctum"},

  [-111]={[0]="TheEyeOfEternity_Continent", [1]="TheEyeOfEternity"},

  [-112]={[0]="Ulduar_Continent", [1]="Ulduar"},
  [-113]={[0]="Ulduar1_Continent", [1]="Ulduar1"},
  [-114]={[0]="Ulduar2_Continent", [1]="Ulduar2"},
  [-115]={[0]="Ulduar3_Continent", [1]="Ulduar3"},
  [-116]={[0]="Ulduar4_Continent", [1]="Ulduar4"},
}

_IdsToSkip = {
    [11189] = true,
    [11241] = true,
    [11343] = true,
    [11344] = true,
    [11402] = true,
    [11429] = true,
    [11436] = true,
    [11460] = true,
    [11472] = true,
    [11485] = true,
    [11491] = true,
    [11495] = true,
    [11570] = true,
    [11592] = true,
    [11652] = true,
    [11664] = true,
    [11673] = true,
    [11705] = true,
    [11708] = true,
    [11711] = true,
    [11719] = true,
    [11878] = true,
    [11890] = true,
    [11930] = true,
    [12027] = true,
    [12028] = true,
    [12032] = true,
    [12033] = true,
    [12036] = true,
    [12053] = true,
    [12082] = true,
    [12135] = true,
    [12139] = true,
    [12150] = true,
    [12263] = true,
    [12301] = true,
    [12321] = true,
    [12327] = true,
    [12330] = true,
    [12427] = true,
    [12428] = true,
    [12429] = true,
    [12430] = true,
    [12470] = true,
    [12473] = true,
    [12506] = true,
    [12536] = true,
    [12537] = true,
    [12570] = true,
    [12573] = true,
    [12578] = true,
    [12665] = true,
    [12671] = true,
    [12687] = true,
    [12688] = true,
    [12720] = true,
    [12721] = true,
    [12816] = true,
    [12817] = true,
    [12821] = true,
    [12832] = true,
    [12842] = true,
    [12864] = true,
    [12932] = true,
    [12933] = true,
    [12934] = true,
    [12935] = true,
    [12936] = true,
    [12948] = true,
    [12954] = true,
    [12973] = true,
    [13047] = true,
    [13053] = true,
    [13141] = true,
    [13343] = true,
    [13377] = true,
    [13405] = true,
    [13407] = true,
    [13417] = true,
    [13427] = true,
    [13428] = true,
    [13429] = true,
    [13830] = true,
    [14163] = true,
    [14164] = true,
    [14178] = true,
    [14179] = true,
    [14180] = true,
    [14181] = true,
    [14182] = true,
    [14183] = true,
    [24216] = true,
    [24217] = true,
    [24218] = true,
    [24219] = true,
    [24220] = true,
    [24221] = true,
    [24223] = true,
    [24224] = true,
    [24225] = true,
    [24426] = true,
    [24427] = true,
}
